# Installation

You can install `gepref_text` via `pip`:

```sh
pip install gepref_text
```

You can also build from source with development dependencies:

```sh
git clone https://github.com/juselara1/gepref_text
cd gepref_text
pip install .[dev]
```
